@@ -5,8 +5,8 @@
 # Minos framework can not be copied and/or distributed without the express
 # permission of Clariteia SL.
 
-from typing import (
-    Any,
+from __future__ import (
+    annotations,
 )
 
 from minos.common import (
@@ -22,12 +22,13 @@ from ..abc import (
 class EventConsumer(Consumer):
     """Event Consumer class."""
 
-    TABLE = "event_queue"
+    TABLE_NAME = "event_queue"
 
-    def __init__(self, *, config: MinosConfig, **kwargs: Any):
-        super().__init__(table_name=self.TABLE, config=config.events, **kwargs)
-        self._kafka_conn_data = f"{config.events.broker.host}:{config.events.broker.port}"
-        self._broker_group_name = f"event_{config.service.name}"
+    @classmethod
+    def _from_config(cls, *args, config: MinosConfig, **kwargs) -> EventConsumer:
+        topics = [item.name for item in config.events.items]
+        kafka_conn_data = f"{config.events.broker.host}:{config.events.broker.port}"
+        return cls(topics=topics, kafka_conn_data=kafka_conn_data, **config.events.queue._asdict(), **kwargs)
 
     def _is_valid_instance(self, value: bytes):
         try:
